==> ruby-rouge_3.28.0.orig.tar.gz: rouge-3.28.0/docs/Languages.md <==
<!--
# @title Languages
-->

# Languages

- ABAP (`abap`)
- ActionScript (`actionscript`)
- Ada (`ada`)
- Apache (`apache`)
- Apex (`apex`)
- API Blueprint (`apiblueprint`)
- AppleScript (`applescript`)
- ArmAsm (`armasm`)
- Augeas (`augeas`)
- Awk (`awk`)
- Batchfile (`batchfile`)
- BBCBASIC (`bbcbasic`)
- BibTeX (`bibtex`)
- BIML (`biml`)
- BPF (`bpf`)
- Brainfuck (`brainfuck`)
- BrightScript (`brightscript`)
- 1C (BSL) (`bsl`)
- C (`c`)
- Ceylon (`ceylon`)
- CFScript (`cfscript`)
- Clean (`clean`)
- Clojure (`clojure`)
- CMake (`cmake`)
- CMHG (`cmhg`)
- CoffeeScript (`coffeescript`)
- Common Lisp (`common_lisp`)
- Config File (`conf`)
- Console (`console`)
- Coq (`coq`)
- C++ (`cpp`)
- Crystal (`crystal`)
- C# (`csharp`)
- CSS (`css`)
- csvs (`csvs`)
- CUDA (`cuda`)
- Cypher (`cypher`)
- Cython (`cython`)
- D (`d`)
- Dafny (`dafny`)
- Dart (`dart`)
- Datastudio (`datastudio`)
- diff (`diff`)
- digdag (`digdag`)
- Docker (`docker`)
- DOT (`dot`)
- ECL (`ecl`)
- EEX (`eex`)
- Eiffel (`eiffel`)
- Elixir (`elixir`)
- Elm (`elm`)
- Email (`email`)
- EPP (`epp`)
- ERB (`erb`)
- Erlang (`erlang`)
- Escape (`escape`)
- Factor (`factor`)
- Fortran (`fortran`)
- FreeFEM (`freefem`)
- FSharp (`fsharp`)
- GDScript (`gdscript`)
- GHC Cmm (C--) (`ghc-cmm`)
- GHC Core (`ghc-core`)
- Gherkin (`gherkin`)
- GLSL (`glsl`)
- Go (`go`)
- Gradle (`gradle`)
- Graphql (`graphql`)
- Groovy (`groovy`)
- Hack (`hack`)
- Haml (`haml`)
- Handlebars (`handlebars`)
- Haskell (`haskell`)
- Haxe (`haxe`)
- Hashicorp Configuration Language (`hcl`)
- HLSL (`hlsl`)
- HOCON (`hocon`)
- HQL (`hql`)
- HTML (`html`)
- HTTP (`http`)
- HyLang (`hylang`)
- IDL (`idlang`)
- IgorPro (`igorpro`)
- INI (`ini`)
- Io (`io`)
- Irb (`irb`)
- Irb_output (`irb_output`)
- ISBL (`isbl`)
- J (`j`)
- Janet (`janet`)
- Java (`java`)
- JavaScript (`javascript`)
- Jinja (`jinja`)
- JSL (`jsl`)
- JSON (`json`)
- Json-doc (`json-doc`)
- Jsonnet (`jsonnet`)
- Jsp (`jsp`)
- JSX (`jsx`)
- Julia (`julia`)
- Kotlin (`kotlin`)
- Lasso (`lasso`)
- Liquid (`liquid`)
- Literate CoffeeScript (`literate_coffeescript`)
- Literate Haskell (`literate_haskell`)
- LiveScript (`livescript`)
- LLVM (`llvm`)
- Lua (`lua`)
- Lustre (`lustre`)
- Lutin (`lutin`)
- M68k (`m68k`)
- Magik (`magik`)
- Make (`make`)
- Markdown (`markdown`)
- Mason (`mason`)
- Mathematica (`mathematica`)
- MATLAB (`matlab`)
- MiniZinc (`minizinc`)
- MoonScript (`moonscript`)
- Mosel (`mosel`)
- MessageTrans (`msgtrans`)
- MXML (`mxml`)
- Nasm (`nasm`)
- NesAsm (`nesasm`)
- nginx (`nginx`)
- Nim (`nim`)
- Nix (`nix`)
- Objective-C (`objective_c`)
- Objective-C++ (`objective_cpp`)
- OCaml (`ocaml`)
- OCL (`ocl`)
- OpenEdge ABL (`openedge`)
- OpenType Feature File (`opentype_feature_file`)
- Pascal (`pascal`)
- Perl (`perl`)
- PHP (`php`)
- Plain Text (`plaintext`)
- Plist (`plist`)
- Pony (`pony`)
- PostScript (`postscript`)
- powershell (`powershell`)
- Praat (`praat`)
- Prolog (`prolog`)
- Prometheus (`prometheus`)
- .properties (`properties`)
- Protobuf (`protobuf`)
- Puppet (`puppet`)
- Python (`python`)
- Q (`q`)
- QML (`qml`)
- R (`r`)
- Racket (`racket`)
- ReasonML (`reasonml`)
- Rego (`rego`)
- ReScript (`rescript`)
- Robot Framework (`robot_framework`)
- Ruby (`ruby`)
- Rust (`rust`)
- SAS (`sas`)
- Sass (`sass`)
- Scala (`scala`)
- Scheme (`scheme`)
- SCSS (`scss`)
- sed (`sed`)
- shell (`shell`)
- Sieve (`sieve`)
- Slice (`slice`)
- Slim (`slim`)
- Smalltalk (`smalltalk`)
- Smarty (`smarty`)
- SML (`sml`)
- Solidity (`solidity`)
- SPARQL (`sparql`)
- SQF (`sqf`)
- SQL (`sql`)
- SSH Config File (`ssh`)
- Stan (`stan`)
- Stata (`stata`)
- SuperCollider (`supercollider`)
- Swift (`swift`)
- Systemd (`systemd`)
- TAP (`tap`)
- Tcl (`tcl`)
- Terraform (`terraform`)
- TeX (`tex`)
- TOML (`toml`)
- TSX (`tsx`)
- TTCN3 (`ttcn3`)
- Tulip (`tulip`)
- Turtle/TriG (`turtle`)
- Twig (`twig`)
- TypeScript (`typescript`)
- Vala (`vala`)
- Visual Basic (`vb`)
- VCL: Varnish Configuration Language (`vcl`)
- Velocity (`velocity`)
- Verilog and System Verilog (`verilog`)
- VHDL 2008 (`vhdl`)
- VimL (`viml`)
- Vue (`vue`)
- Wollok (`wollok`)
- XML (`xml`)
- Xojo (`xojo`)
- XPath (`xpath`)
- XQuery (`xquery`)
- YAML (`yaml`)
- YANG (`yang`)
- Zig (`zig`)

==> ruby-rouge_3.30.0.orig.tar.gz: rouge-3.30.0/docs/Languages.md <==
<!--
# @title Languages
-->

# Languages

- ABAP (`abap`)
- ActionScript (`actionscript`)
- Ada (`ada`)
- Apache (`apache`)
- Apex (`apex`)
- API Blueprint (`apiblueprint`)
- AppleScript (`applescript`)
- ArmAsm (`armasm`)
- Augeas (`augeas`)
- Awk (`awk`)
- Batchfile (`batchfile`)
- BBCBASIC (`bbcbasic`)
- BibTeX (`bibtex`)
- BIML (`biml`)
- BPF (`bpf`)
- Brainfuck (`brainfuck`)
- BrightScript (`brightscript`)
- 1C (BSL) (`bsl`)
- C (`c`)
- Ceylon (`ceylon`)
- CFScript (`cfscript`)
- Clean (`clean`)
- Clojure (`clojure`)
- CMake (`cmake`)
- CMHG (`cmhg`)
- CoffeeScript (`coffeescript`)
- Common Lisp (`common_lisp`)
- Config File (`conf`)
- Console (`console`)
- Coq (`coq`)
- C++ (`cpp`)
- Crystal (`crystal`)
- C# (`csharp`)
- CSS (`css`)
- csvs (`csvs`)
- CUDA (`cuda`)
- Cypher (`cypher`)
- Cython (`cython`)
- D (`d`)
- Dafny (`dafny`)
- Dart (`dart`)
- Datastudio (`datastudio`)
- diff (`diff`)
- digdag (`digdag`)
- Docker (`docker`)
- DOT (`dot`)
- ECL (`ecl`)
- EEX (`eex`)
- Eiffel (`eiffel`)
- Elixir (`elixir`)
- Elm (`elm`)
- Email (`email`)
- EPP (`epp`)
- ERB (`erb`)
- Erlang (`erlang`)
- Escape (`escape`)
- Factor (`factor`)
- Fortran (`fortran`)
- FreeFEM (`freefem`)
- FSharp (`fsharp`)
- GDScript (`gdscript`)
- GHC Cmm (C--) (`ghc-cmm`)
- GHC Core (`ghc-core`)
- Gherkin (`gherkin`)
- GLSL (`glsl`)
- Go (`go`)
- Gradle (`gradle`)
- Graphql (`graphql`)
- Groovy (`groovy`)
- Hack (`hack`)
- Haml (`haml`)
- Handlebars (`handlebars`)
- Haskell (`haskell`)
- Haxe (`haxe`)
- Hashicorp Configuration Language (`hcl`)
- HLSL (`hlsl`)
- HOCON (`hocon`)
- HQL (`hql`)
- HTML (`html`)
- HTTP (`http`)
- HyLang (`hylang`)
- IDL (`idlang`)
- Idris (`idris`)
- IgorPro (`igorpro`)
- INI (`ini`)
- Io (`io`)
- Irb (`irb`)
- Irb_output (`irb_output`)
- Isabelle (`isabelle`)
- ISBL (`isbl`)
- J (`j`)
- Janet (`janet`)
- Java (`java`)
- JavaScript (`javascript`)
- Jinja (`jinja`)
- JSL (`jsl`)
- JSON (`json`)
- Json-doc (`json-doc`)
- Jsonnet (`jsonnet`)
- Jsp (`jsp`)
- JSX (`jsx`)
- Julia (`julia`)
- Kotlin (`kotlin`)
- Lasso (`lasso`)
- Lean (`lean`)
- Liquid (`liquid`)
- Literate CoffeeScript (`literate_coffeescript`)
- Literate Haskell (`literate_haskell`)
- LiveScript (`livescript`)
- LLVM (`llvm`)
- Lua (`lua`)
- Lustre (`lustre`)
- Lutin (`lutin`)
- M68k (`m68k`)
- Magik (`magik`)
- Make (`make`)
- Markdown (`markdown`)
- Mason (`mason`)
- Mathematica (`mathematica`)
- MATLAB (`matlab`)
- Meson (`meson`)
- MiniZinc (`minizinc`)
- MoonScript (`moonscript`)
- Mosel (`mosel`)
- MessageTrans (`msgtrans`)
- MXML (`mxml`)
- Nasm (`nasm`)
- NesAsm (`nesasm`)
- nginx (`nginx`)
- Nial (`nial`)
- Nim (`nim`)
- Nix (`nix`)
- Objective-C (`objective_c`)
- Objective-C++ (`objective_cpp`)
- OCaml (`ocaml`)
- OCL (`ocl`)
- OpenEdge ABL (`openedge`)
- OpenType Feature File (`opentype_feature_file`)
- Pascal (`pascal`)
- Perl (`perl`)
- PHP (`php`)
- Plain Text (`plaintext`)
- Plist (`plist`)
- PLSQL (`plsql`)
- Pony (`pony`)
- PostScript (`postscript`)
- powershell (`powershell`)
- Praat (`praat`)
- Prolog (`prolog`)
- Prometheus (`prometheus`)
- .properties (`properties`)
- Protobuf (`protobuf`)
- Puppet (`puppet`)
- Python (`python`)
- Q (`q`)
- QML (`qml`)
- R (`r`)
- Racket (`racket`)
- ReasonML (`reasonml`)
- Rego (`rego`)
- ReScript (`rescript`)
- Robot Framework (`robot_framework`)
- Ruby (`ruby`)
- Rust (`rust`)
- SAS (`sas`)
- Sass (`sass`)
- Scala (`scala`)
- Scheme (`scheme`)
- SCSS (`scss`)
- sed (`sed`)
- shell (`shell`)
- Sieve (`sieve`)
- Slice (`slice`)
- Slim (`slim`)
- Smalltalk (`smalltalk`)
- Smarty (`smarty`)
- SML (`sml`)
- Solidity (`solidity`)
- SPARQL (`sparql`)
- SQF (`sqf`)
- SQL (`sql`)
- SSH Config File (`ssh`)
- Stan (`stan`)
- Stata (`stata`)
- SuperCollider (`supercollider`)
- Swift (`swift`)
- Systemd (`systemd`)
- Syzlang (`syzlang`)
- Syzprog (`syzprog`)
- TAP (`tap`)
- Tcl (`tcl`)
- Terraform (`terraform`)
- TeX (`tex`)
- TOML (`toml`)
- TSX (`tsx`)
- TTCN3 (`ttcn3`)
- Tulip (`tulip`)
- Turtle/TriG (`turtle`)
- Twig (`twig`)
- TypeScript (`typescript`)
- Vala (`vala`)
- Visual Basic (`vb`)
- VCL: Varnish Configuration Language (`vcl`)
- Velocity (`velocity`)
- Verilog and System Verilog (`verilog`)
- VHDL 2008 (`vhdl`)
- VimL (`viml`)
- Vue (`vue`)
- Wollok (`wollok`)
- XML (`xml`)
- Xojo (`xojo`)
- XPath (`xpath`)
- XQuery (`xquery`)
- YAML (`yaml`)
- YANG (`yang`)
- Zig (`zig`)
